@@ -1,10 +1,29 @@
 /******************************************************************************
- *  rawverse.h   - code for class 'zVerse'- a module that reads raw text
+ *
+ *  rawverse.h -	code for class 'zVerse'- a module that reads raw text
  *			files:  ot and nt using indexs ??.bks ??.cps ??.vss
  *			and provides lookup and parsing functions based on
  *			class VerseKey
+ *
+ * $Id: zverse.h 2833 2013-06-29 06:40:28Z chrislit $
+ *
+ * Copyright 2000-2013 CrossWire Bible Society (http://www.crosswire.org)
+ *	CrossWire Bible Society
+ *	P. O. Box 2528
+ *	Tempe, AZ  85280-2528
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation version 2.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
  */
 
+
 #ifndef ZVERSE_H
 #define ZVERSE_H
 
@@ -28,12 +47,12 @@ protected:
 	char *path;
 	void doSetText(char testmt, long idxoff, const char *buf, long len = 0);
 	void doLinkEntry(char testmt, long destidxoff, long srcidxoff);
-	void flushCache();
-	char *cacheBuf;
-	unsigned int cacheBufSize;
-	char cacheTestament;
-	long cacheBufIdx;
-	bool dirtyCache;
+	void flushCache() const;
+	mutable char *cacheBuf;
+	mutable unsigned int cacheBufSize;
+	mutable char cacheTestament;
+	mutable long cacheBufIdx;
+	mutable bool dirtyCache;
 
 public:
 
@@ -50,8 +69,8 @@ public:
 	virtual ~zVerse();
 
 	void findOffset(char testmt, long idxoff, long *start, unsigned short *size, unsigned long *buffnum) const;
-	void zReadText(char testmt, long start, unsigned short size, unsigned long buffnum, SWBuf &buf);
-	virtual void rawZFilter(SWBuf &buf, char direction = 0) {}
+	void zReadText(char testmt, long start, unsigned short size, unsigned long buffnum, SWBuf &buf) const;
+	virtual void rawZFilter(SWBuf &buf, char direction = 0) const { (void) buf; (void) direction; }
 	static char createModule(const char *path, int blockBound, const char *v11n = "KJV");
 };
 
