@@ -1,11 +1,10 @@
 /***************************************************************************
- *                     osisrtf.cpp  -  OSIS to RTF filter
- *                            -------------------
- *   begin                : 2003-02-15
- *   copyright            : 2003 by CrossWire Bible Society
  *
+ *  osisrtf.cpp -	OSIS to RTF filter
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * $Id: osisrtf.cpp 2980 2013-09-14 21:51:47Z scribe $ *
+ *
+ * Copyright 2003-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -53,8 +52,8 @@ namespace {
 		BiblicalText  = false;
 		suspendLevel  = 0;
 		if (module) {
-			version = module->Name();
-			BiblicalText = (!strcmp(module->Type(), "Biblical Texts"));
+			version = module->getName();
+			BiblicalText = (!strcmp(module->getType(), "Biblical Texts"));
 		}	
 		osisQToTick = ((!module->getConfigEntry("OSISqToTick")) || (strcmp(module->getConfigEntry("OSISqToTick"), "false")));
 	}
@@ -68,9 +67,11 @@ namespace {
 			delete [] tagData;
 		}
 	}
-static inline void outText(const char *t, SWBuf &o, BasicFilterUserData *u) { if (!u->suspendTextPassThru) o += t; else u->lastSuspendSegment += t; }
-static inline void outText(char t, SWBuf &o, BasicFilterUserData *u) { if (!u->suspendTextPassThru) o += t; else u->lastSuspendSegment += t; }
-};
+
+	static inline void outText(const char *t, SWBuf &o, BasicFilterUserData *u) { if (!u->suspendTextPassThru) o += t; else u->lastSuspendSegment += t; }
+	static inline void outText(char t, SWBuf &o, BasicFilterUserData *u) { if (!u->suspendTextPassThru) o += t; else u->lastSuspendSegment += t; }
+
+}
 
 
 OSISRTF::OSISRTF() {
@@ -87,8 +88,8 @@ OSISRTF::OSISRTF() {
 	addEscapeStringSubstitute("lt", "<");
 	addEscapeStringSubstitute("gt", ">");
 	addEscapeStringSubstitute("quot", "\"");
-	addTokenSubstitute("lg", "{\\par}");
-	addTokenSubstitute("/lg", "{\\par}");
+	//	addTokenSubstitute("lg", "{\\par}");
+	//	addTokenSubstitute("/lg", "{\\par}");
 
 	setTokenCaseSensitive(true);
 }
@@ -239,8 +240,8 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 				if (!tag.isEmpty()) {
 					SWBuf type = tag.getAttribute("type");
 
-					if (		   (type != "x-strongsMarkup")	// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
-							&& (type != "strongsMarkup")		// deprecated
+					if ((type != "x-strongsMarkup")			// leave strong's markup notes out, in the future we'll probably have different option filters to turn different note types on or off
+							&& (type != "strongsMarkup")	// deprecated
 							) {
 						SWBuf footnoteNumber = tag.getAttribute("swordFootnote");
 						VerseKey *vkey = NULL;
@@ -251,7 +252,7 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 						SWCATCH ( ... ) {	}
 						if (vkey) {
 							char ch = ((!strcmp(type.c_str(), "crossReference")) || (!strcmp(type.c_str(), "x-cross-ref"))) ? 'x':'n';
-							scratch.setFormatted("{\\super <a href=\"\">*%c%i.%s</a>} ", ch, vkey->Verse(), footnoteNumber.c_str());
+							scratch.setFormatted("{\\super <a href=\"\">*%c%i.%s</a>} ", ch, vkey->getVerse(), footnoteNumber.c_str());
 							outText(scratch.c_str(), buf, u);
 							u->inXRefNote = (ch == 'x');
 						}
@@ -265,8 +266,8 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 			}
 		}
 
-		// <p> paragraph tag
-		else if (!strcmp(tag.getName(), "p")) {
+		// <p> paragraph and <lg> linegroup tags
+		else if (!strcmp(tag.getName(), "p") || !strcmp(tag.getName(), "lg")) {
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {	// non-empty start tag
 				outText("{\\fi200\\par}", buf, u);
 			}
@@ -275,7 +276,7 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 				userData->supressAdjacentWhitespace = true;
 			}
 			else {					// empty paragraph break marker
-				outText("{\\pard\\par\\par}", buf, u);
+				outText("{\\pard\\par}", buf, u);
 				userData->supressAdjacentWhitespace = true;
 			}
 		}
@@ -373,7 +374,7 @@ bool OSISRTF::handleToken(SWBuf &buf, const char *token, BasicFilterUserData *us
 		else if (!strcmp(tag.getName(), "hi")) {
 			SWBuf type = tag.getAttribute("type");
 			if ((!tag.isEndTag()) && (!tag.isEmpty())) {
-				if (type == "b" || type == "x-b")
+				if (type == "bold" || type == "b" || type == "x-b")
 					outText("{\\b1 ", buf, u);
 				else	// all other types
 					outText("{\\i1 ", buf, u);
