@@ -1,10 +1,11 @@
 /******************************************************************************
  *
- * thmlheadings -	SWFilter descendant to hide or show headings
- *			in a ThML module.
+ *  thmlheadings.cpp -	SWFilter descendant to hide or show headings
+ *			in a ThML module
  *
+ * $Id: thmlheadings.cpp 2980 2013-09-14 21:51:47Z scribe $
  *
- * Copyright 2009 CrossWire Bible Society (http://www.crosswire.org)
+ * Copyright 2001-2013 CrossWire Bible Society (http://www.crosswire.org)
  *	CrossWire Bible Society
  *	P. O. Box 2528
  *	Tempe, AZ  85280-2528
@@ -28,16 +29,23 @@
 #include <swmodule.h>
 #include <stdio.h>
 
+
 SWORD_NAMESPACE_START
 
-const char oName[] = "Headings";
-const char oTip[] = "Toggles Headings On and Off if they exist";
+namespace {
 
-const SWBuf choices[3] = {"Off", "On", ""};
-const StringList oValues(&choices[0], &choices[2]);
+	static const char oName[] = "Headings";
+	static const char oTip[]  = "Toggles Headings On and Off if they exist";
 
-ThMLHeadings::ThMLHeadings() : SWOptionFilter(oName, oTip, &oValues) {
-	setOptionValue("Off");
+	static const StringList *oValues() {
+		static const SWBuf choices[3] = {"Off", "On", ""};
+		static const StringList oVals(&choices[0], &choices[2]);
+		return &oVals;
+	}
+}
+
+
+ThMLHeadings::ThMLHeadings() : SWOptionFilter(oName, oTip, oValues()) {
 }
 
 
